/**
 * Copyright (c) 2008 Janne Ohtonen. All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.liferay.panorama.action;

import com.liferay.portal.kernel.portlet.ConfigurationAction;
import com.liferay.portal.kernel.util.Constants;
import com.liferay.portal.kernel.util.ParamUtil;
import com.liferay.portlet.PortletPreferencesFactoryUtil;

import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;
import javax.portlet.PortletConfig;
import javax.portlet.PortletPreferences;
import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;

/**
 * <a href="ConfigurationActionImpl.java.html"><b><i>View Source</i></b></a>
 *
 * @author Janne Ohtonen
 *
 */
public class ConfigurationActionImpl implements ConfigurationAction {

	public void processAction(
			PortletConfig portletConfig, ActionRequest actionRequest,
			ActionResponse actionResponse)
		throws Exception {

		String cmd = ParamUtil.getString(actionRequest, Constants.CMD);

		if (!cmd.equals(Constants.UPDATE)) {
			return;
		}

		String jarfile = ParamUtil.getString(actionRequest, "jarfile");
		String imageUrl = ParamUtil.getString(actionRequest, "imageUrl");
		String splashUrl = ParamUtil.getString(actionRequest, "splashUrl");
		String splashBgcolor = ParamUtil.getString(actionRequest, "splashBgcolor");
		String overlayUrl = ParamUtil.getString(actionRequest, "overlayUrl");
		
		String initAutorot = ParamUtil.getString(actionRequest, "initAutorot");
		String initRenderQuality = ParamUtil.getString(actionRequest, "initRenderQuality");
		String initRenderPanMode = ParamUtil.getString(actionRequest, "initRenderPanMode");

		String viewCaption = ParamUtil.getString(actionRequest, "viewCaption");
		String viewHfov = ParamUtil.getString(actionRequest, "viewHfov");
		String viewLimitHfovMin = ParamUtil.getString(actionRequest, "viewLimitHfovMin");
		String viewLimitHfovMax = ParamUtil.getString(actionRequest, "viewLimitHfovMax");
		String viewPan = ParamUtil.getString(actionRequest, "viewPan");
		String viewLimitPanMin = ParamUtil.getString(actionRequest, "viewLimitPanMin");
		String viewLimitPanMax = ParamUtil.getString(actionRequest, "viewLimitPanMax");
		String viewTilt = ParamUtil.getString(actionRequest, "viewTilt");
		String viewLimitTiltMin = ParamUtil.getString(actionRequest, "viewLimitTiltMin");
		String viewLimitTiltMax = ParamUtil.getString(actionRequest, "viewLimitTiltMax");
		
		String height = ParamUtil.getString(actionRequest, "height");
		String width = ParamUtil.getString(actionRequest, "width");
		String message = ParamUtil.getString(actionRequest, "message");

		String portletResource = ParamUtil.getString(
			actionRequest, "portletResource");

		PortletPreferences preferences =
			PortletPreferencesFactoryUtil.getPortletSetup(
				actionRequest, portletResource);

		preferences.setValue("jarfile", jarfile);
		preferences.setValue("imageUrl", imageUrl);
		preferences.setValue("splashUrl", splashUrl);
		preferences.setValue("splashBgcolor", splashBgcolor);
		preferences.setValue("overlayUrl", overlayUrl);
		
		preferences.setValue("initAutorot", initAutorot);
		preferences.setValue("initRenderQuality", initRenderQuality);
		preferences.setValue("initRenderPanMode", initRenderPanMode);
		
		preferences.setValue("viewCaption", viewCaption);
		preferences.setValue("viewHfov", viewHfov);
		preferences.setValue("viewLimitHfovMin", viewLimitHfovMin);
		preferences.setValue("viewLimitHfovMax", viewLimitHfovMax);
		preferences.setValue("viewPan", viewPan);
		preferences.setValue("viewLimitPanMin", viewLimitPanMin);
		preferences.setValue("viewLimitPanMax", viewLimitPanMax);
		preferences.setValue("viewTilt", viewTilt);
		preferences.setValue("viewLimitTiltMin", viewLimitTiltMin);
		preferences.setValue("viewLimitTiltMax", viewLimitTiltMax);
		
		preferences.setValue("height", height);
		preferences.setValue("width", width);
		preferences.setValue("message", message);

		preferences.store();
	}

	public String render(
			PortletConfig portletConfig, RenderRequest renderRequest,
			RenderResponse renderResponse)
		throws Exception {

		return "/configuration.jsp";
	}

}